summaryrefslogtreecommitdiff
path: root/src/gc/gc.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gc/gc.h')
-rw-r--r--src/gc/gc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gc/gc.h b/src/gc/gc.h
index a661c311ab..07ae6c916c 100644
--- a/src/gc/gc.h
+++ b/src/gc/gc.h
@@ -115,7 +115,7 @@ extern "C" GCHeapType g_gc_heap_type;
extern "C" uint32_t g_max_generation;
extern "C" MethodTable* g_gc_pFreeObjectMethodTable;
-::IGCHandleTable* CreateGCHandleTable();
+::IGCHandleManager* CreateGCHandleManager();
namespace WKS {
::IGCHeapInternal* CreateGCHeap();
@@ -260,8 +260,8 @@ void updateGCShadow(Object** ptr, Object* val);
// The single GC heap instance, shared with the VM.
extern IGCHeapInternal* g_theGCHeap;
-// The single GC handle table instance, shared with the VM.
-extern IGCHandleTable* g_theGCHandleTable;
+// The single GC handle manager instance, shared with the VM.
+extern IGCHandleManager* g_theGCHandleManager;
#ifndef DACCESS_COMPILE
inline bool IsGCInProgress(bool bConsiderGCStart = false)